Struct style::custom_properties::VariableValue
[−]
[src]
pub struct VariableValue { /* fields omitted */ }A value for a custom property is just a set of tokens.
We preserve the original CSS for serialization, and also the variable references to other custom property names.
Methods
impl VariableValue[src]
pub fn parse<'i, 't>(
input: &mut Parser<'i, 't>
) -> Result<Arc<Self>, ParseError<'i>>[src]
input: &mut Parser<'i, 't>
) -> Result<Arc<Self>, ParseError<'i>>
Parse a custom property value.